@@ -1,6 +1,6 @@
 setMethod("show", signature(object = "evaluationResults"),
   function(object) {
-    writeLines(sprintf("Evaluation results for %d runs using method %s.",
+    writeLines(sprintf("Evaluation results for %d folds/samples using method %s.",
       getRuns(object), sQuote(object@method)))
     if(any(!sapply(getModel(object), is.null)))
       writeLines("Result contains predictive models!")
